==> haskell-http-download-0.2.1.0-249-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-JDO2q5Gn2V3FjPyIVhd1ce
key:                  http-download-0.2.1.0-JDO2q5Gn2V3FjPyIVhd1ce
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  be3c5bc483e26c433bb2304dbd9784d2
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-JDO2q5Gn2V3FjPyIVhd1ce
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-3cCVQioh572KzPLHpOFxfQ
    bytestring-0.11.5.3 conduit-1.3.6.1-He7eBVLUt4xGGZqD48fwnz
    conduit-extra-1.3.8-FPYZ2SHai5SFHdZmLa2NAW
    crypton-1.0.2-a36K9vGBi7Hapm36fFP7g
    crypton-conduit-0.2.3-HxkBx58VKx09nfG8ZIiFIf directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.19-4PBxl7ykGvY1A1M3m4syiA
    http-conduit-2.3.9.1-Htpo5ybm1VnLc22xTZEyI8
    http-types-0.12.4-5NSSMgOt7vT4e8131JaEsZ
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    path-0.9.5-1BpMqMzB0SMFJwBk1CbDOb
    path-io-1.8.2-C5UHDpXx5sj4fy7wX782KM
    retry-0.9.3.1-5xo7GcP1PGDD02FaZ43hls
    rio-0.1.22.0-JWvvEymNAMu3VyyPAfG55D
    rio-prettyprint-0.1.8.0-IAExzfoGN4c7fMWjDqkGdg

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.2.1.0-250-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-4skwSX9Vajz7oYDMKuH6IL
key:                  http-download-0.2.1.0-4skwSX9Vajz7oYDMKuH6IL
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  f21e06fc4c1883202572a9fd886fd0ce
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-4skwSX9Vajz7oYDMKuH6IL
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-3cCVQioh572KzPLHpOFxfQ
    bytestring-0.11.5.3 conduit-1.3.6.1-He7eBVLUt4xGGZqD48fwnz
    conduit-extra-1.3.8-FPYZ2SHai5SFHdZmLa2NAW
    crypton-1.0.2-a36K9vGBi7Hapm36fFP7g
    crypton-conduit-0.2.3-HxkBx58VKx09nfG8ZIiFIf directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    http-client-0.7.19-4PBxl7ykGvY1A1M3m4syiA
    http-conduit-2.3.9.1-Htpo5ybm1VnLc22xTZEyI8
    http-types-0.12.4-5NSSMgOt7vT4e8131JaEsZ
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    path-0.9.5-1BpMqMzB0SMFJwBk1CbDOb
    path-io-1.8.2-4DJZcBOpJ2GBhrAPgZ9965
    retry-0.9.3.1-5xo7GcP1PGDD02FaZ43hls
    rio-0.1.22.0-JWvvEymNAMu3VyyPAfG55D
    rio-prettyprint-0.1.8.0-IAExzfoGN4c7fMWjDqkGdg

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
